@@ -74,12 +74,25 @@
 // #define ARMA_BLAS_LONG_LONG
 //// Uncomment the above line if your BLAS and LAPACK libraries use "long long" instead of "int"
 
+#define ARMA_USE_FORTRAN_HIDDEN_ARGS
+//// Comment out the above line to call BLAS and LAPACK functions without using so-called "hidden" arguments.
+//// Fortran functions (compiled without a BIND(C) declaration) that have char arguments
+//// (like many BLAS and LAPACK functions) also have associated "hidden" arguments.
+//// For each char argument, the corresponding "hidden" argument specifies the number of characters.
+//// These "hidden" arguments are typically tacked onto the end of function definitions.
+
 // #define ARMA_USE_TBB_ALLOC
 //// Uncomment the above line if you want to use Intel TBB scalable_malloc() and scalable_free() instead of standard malloc() and free()
 
 // #define ARMA_USE_MKL_ALLOC
 //// Uncomment the above line if you want to use Intel MKL mkl_malloc() and mkl_free() instead of standard malloc() and free()
 
+// #define ARMA_USE_MKL_TYPES
+//// Uncomment the above line if you want to use Intel MKL types for complex numbers.
+//// You will need to include appropriate MKL headers before the Armadillo header.
+//// You may also need to enable or disable the following options:
+//// ARMA_BLAS_LONG, ARMA_BLAS_LONG_LONG, ARMA_USE_FORTRAN_HIDDEN_ARGS
+
 // #define ARMA_USE_ATLAS
 // #define ARMA_ATLAS_INCLUDE_DIR /usr/include/
 //// If you're using ATLAS and the compiler can't find cblas.h and/or clapack.h
@@ -117,6 +130,11 @@
   //// Comment out the above line if you don't want optimised handling of band matrices by solve()
 #endif
 
+#if !defined(ARMA_OPTIMISE_SOLVE_SYMPD)
+  #define ARMA_OPTIMISE_SOLVE_SYMPD
+  //// Comment out the above line if you don't want optimised handling of symmetric/hermitian positive definite matrices by solve()
+#endif
+
 // #define ARMA_USE_HDF5_ALT
 #if defined(ARMA_USE_HDF5_ALT) && defined(ARMA_USE_WRAPPER)
   #undef  ARMA_USE_HDF5
@@ -134,7 +152,7 @@
 //// change the number to the size of your vectors.
 
 #if !defined(ARMA_OPENMP_THRESHOLD)
-  #define ARMA_OPENMP_THRESHOLD 320
+  #define ARMA_OPENMP_THRESHOLD 240
 #endif
 //// The minimum number of elements in a matrix to allow OpenMP based parallelisation;
 //// it must be an integer that is at least 1.
@@ -145,13 +163,6 @@
 //// The maximum number of threads to use for OpenMP based parallelisation;
 //// it must be an integer that is at least 1.
 
-#if !defined(ARMA_SPMAT_CHUNKSIZE)
-  #define ARMA_SPMAT_CHUNKSIZE 256
-#endif
-//// This is the minimum increase in the amount of memory (in terms of elements) allocated by a sparse matrix;
-//// it must be an integer that is at least 1.
-//// The minimum recommended size is 16.
-
 // #define ARMA_NO_DEBUG
 //// Uncomment the above line if you want to disable all run-time checks.
 //// This will result in faster code, but you first need to make sure that your code runs correctly!
@@ -229,6 +240,10 @@
   #undef ARMA_USE_HDF5_ALT
 #endif
 
+#if defined(ARMA_DONT_USE_FORTRAN_HIDDEN_ARGS)
+  #undef ARMA_USE_FORTRAN_HIDDEN_ARGS
+#endif
+
 #if defined(ARMA_DONT_USE_CXX11)
   #undef ARMA_USE_CXX11
   #undef ARMA_USE_EXTERN_CXX11_RNG
@@ -263,6 +278,10 @@
   #undef ARMA_OPTIMISE_SOLVE_BAND
 #endif
 
+#if defined(ARMA_DONT_OPTIMISE_SOLVE_SYMPD)
+  #undef ARMA_OPTIMISE_SOLVE_SYMPD
+#endif
+
 #if defined(ARMA_DONT_PRINT_ERRORS)
   #undef ARMA_PRINT_ERRORS
 #endif
